<?php

namespace App\Http\Controllers;

use App\Mail\AccountConfirmation;
use App\Models\CareerJobs;
use App\Models\Categories;
use App\Models\ContactMessage;
use App\Models\Contactus;
use App\Models\Instagramimages;
use App\Models\Jobs;
use App\Models\Newsletter;
use App\Models\Orders;
use App\Models\OrderUserDetail;
use App\Models\Products;
use App\Models\Services;
use App\Models\Setting;
use App\Models\Subscription;
use App\Models\Tours;
use App\Models\User;
use Auth;
use Hash;
use Illuminate\Http\Request;
use Validator;
use Illuminate\Support\Facades\Mail;



class AdminHomeController extends Controller
{
    public function Dashboard()
    {
        $website = Setting::first();
        $active_orders = 1;
        $categories = Categories::count();
        $jobs = Jobs::count();
        $careerjobs = CareerJobs::count();
        $contactmessages = ContactMessage::count();
        return view('admin.index', compact('website', 'active_orders', 'categories', 'jobs', 'careerjobs', 'contactmessages'));
    }

    public function AdminProfile()
    {
        $admin = User::findOrFail(Auth::guard('admin')->user()->id);
        return view("admin.profile", compact("admin"));
    }

    public function updateprofile(Request $request)
    {
        $GetData = User::findOrFail(Auth::guard('admin')->user()->id);
        if (isset($request->name)) {
            $GetData->name = $request->name;
        }

        if (isset($request->phone)) {
            $GetData->phone = $request->phone;
        }

        if (isset($request->address)) {
            $GetData->address = $request->address;
        }

        if (isset($request->email)) {
            $GetData->email = $request->email;
        }
        if (isset($request->password)) {

            $validator = Validator::make($request->all(), [
                'password' => 'required|string|min:8'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Please Enter Valid Password !');
            }
            $GetData->password = Hash::make($request->password);
        }

        if ($request->hasFile('profile')) {
            $validator = Validator::make($request->all(), [
                'profile' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Invalid Profile Picture');
            }

            if (\File::exists(public_path('admin/assets/uploads/' . $GetData->image))) {

                \File::delete(public_path('admin/assets/uploads/' . $GetData->image));
            }

            $image = $request->file('profile');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $GetData->image = $image_new;
        }

        $GetData->save();
        return back()->with('success', __('language.successfully_updated'));
    }

    public function contact_messages()
    {
        $contact_messages = ContactMessage::all();
        return view("admin.contact_messages", compact('contact_messages'));
    }

    public function delete_contact_message($id)
    {
        $getData = ContactMessage::findOrFail(decrypt($id));
        $getData->delete();
        return back()->with('success', __('language.successfully_deleted'));
    }

    public function instagram_images()
    {
        $images = Instagramimages::get();
        return view("admin.instagram_images", compact('images'));
    }

    public function saveinstagramimages(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'image' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $data['image'] = $image_new;
            Instagramimages::create($data);
        }
        return redirect()->back()->with('success', 'Successfully Added.');
    }

    public function delete_instagram_image($id)
    {
        $getData = Instagramimages::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {
            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function users_list()
    {
        $users = User::where('type','!=','admin')->get();
        return view("admin.users_list", compact('users'));
    }

    public function make_user_status_inactive($id)
    {
        User::findOrFail(decrypt($id))->update(["status" => "inactive"]);
        return redirect()->back()->with('success', 'Successfully Updated.');
    }

    public function make_user_email_status_inactive($id)
    {
        User::findOrFail(decrypt($id))->update(["email_verification" => "0"]);
        return redirect()->back()->with('success', 'Successfully Updated.');
    }

    public function make_user_status_active($id)
    {
        User::findOrFail(decrypt($id))->update(["status" => "active"]);
        return redirect()->back()->with('success', 'Successfully Updated.');
    }

    public function make_user_email_status_active($id)
    {
        User::findOrFail(decrypt($id))->update(["email_verification" => "1"]);
        return redirect()->back()->with('success', 'Successfully Updated.');
    }

    public function send_email_verification($id)
    {
        $maildata = User::findOrFail(decrypt($id));
        Mail::to($maildata->email)->send(new AccountConfirmation($maildata));
        return redirect()->back()->with('success', 'Email Sent Successfully.');
    }

    public function deleted_user($id)
    {
        $maildata = User::findOrFail(decrypt($id))->delete();
        return redirect()->back()->with('success', 'Successfully Deleted.');
    }

}
