<?php

namespace App\Http\Controllers;

use App\Models\Blogscategories;
use App\Models\ContactMessage;
use App\Models\Hobbies;
use App\Models\Intrests;
use App\Models\Lifestyle;
use App\Models\Setting;
use App\Models\TourCategories;
use App\Models\Tourimages;
use App\Models\Tours;
use App\Models\User;
use App\Models\UserHobbies;
use App\Models\UserImages;
use App\Models\UserInterests;
use App\Models\UserLanguages;
use App\Models\UserLifestyle;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Hash;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;
use Intervention\Image\ImageManagerStatic as Image;

class HostController extends Controller
{
    public function dashboard(Request $request)
    {
        $tours = Tours::where('userid',Auth::guard('host')->user()->id)->orderBy('id','desc')->limit(8)->get();
        return view('host.index',compact('tours'));
    }

    public function hostlogout(Request $request)
    {
        Auth::guard('host')->logout();
        return redirect()->route("login")->with('success', 'Successfully Logout.');
    }

    public function profile()
    {
//        $a = ["Charity work", "Culture", "Events & social", "Farming", "Fashion or beauty", "LGBTQ", "Movies & TV", "Pets", "Politics / Social justice", "Self development", "Sustainability", "Technology", "Van life", "Vegetarian or vegan", "Videography"];
//        foreach($a as $aa)
//        {
//            $data['name'] = $aa;
//            Lifestyle::create($data);
//        }

        $intrests = Intrests::all();
        $hobbies = Hobbies::all();
        $lifestyle = Lifestyle::all();
        $host = User::findOrFail(Auth::guard('host')->user()->id);
        $userInterests = UserInterests::where('userid', Auth::guard('host')->user()->id)->pluck('interestid')->toArray();
        $userHobbies = UserHobbies::where('userid', Auth::guard('host')->user()->id)->pluck('hobbyid')->toArray();
        $userLifestyle = UserLifestyle::where('userid', Auth::guard('host')->user()->id)->pluck('lifestyleid')->toArray();
        $userLanguages = UserLanguages::where('userid', Auth::guard('host')->user()->id)->get();
        return view("host.profile",compact('host','intrests','hobbies','lifestyle','userInterests','userHobbies','userLifestyle','userLanguages'));
    }

    public function update_host_overview(Request $request)
    {
        $GetData = User::findOrFail(Auth::guard('host')->user()->id);
        $GetData->fname = $request->fname;
        $GetData->lname = $request->lname;
        $GetData->phone = $request->phone;
        $GetData->country = $request->country;
        $GetData->state = $request->state;
        $GetData->city = $request->city;
        $GetData->address = $request->address;
        $GetData->about_me = $request->about_me;

        if (isset($request->password)) {

            $validator = Validator::make($request->all(), [
                'password' => 'required|string|min:8'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Please Enter Valid Password !');
            }
            $GetData->password = Hash::make($request->password);
        }

        if ($request->hasFile('profile')) {
            $validator = Validator::make($request->all(), [
                'profile' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Invalid Profile Picture');
            }

            if (\File::exists(public_path('admin/assets/uploads/' . $GetData->image))) {

                \File::delete(public_path('admin/assets/uploads/' . $GetData->image));
            }

            $image = $request->file('profile');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $GetData->image = $image_new;
        }

        $GetData->save();
        return back()->with('success', __('language.successfully_updated'));
    }

    public function save_host_images(Request $request)
    {
        if ($request->hasFile('profile')) {
            $validator = Validator::make($request->all(), [
                'profile' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Invalid Picture');
            }

            $image = $request->file('profile');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $GetData['userid'] = Auth::guard('host')->user()->id;
            $GetData['image'] = $image_new;
            UserImages::create($GetData);
        }
        return back()->with('success', __('language.successfully_added'));
    }

    public function save_interests(Request $request)
    {
        if (isset($request->intrests))
        {
            $size = sizeof($request->intrests);
            if($size>0)
            {
                UserInterests::where('userid',Auth::guard('host')->user()->id)->delete();
                for($i=0;$i<$size;$i++)
                {
                    $int['userid'] = Auth::guard('host')->user()->id;
                    $int['interestid'] = $request->intrests[$i];
                    UserInterests::create($int);
                }
            }
        }
        if (isset($request->hobbies))
        {
            $size1 = sizeof($request->hobbies);
            if($size1>0)
            {
                UserHobbies::where('userid',Auth::guard('host')->user()->id)->delete();
                for($ii=0;$ii<$size1;$ii++)
                {
                    $hobb['userid'] = Auth::guard('host')->user()->id;
                    $hobb['hobbyid'] = $request->hobbies[$ii];
                    UserHobbies::create($hobb);
                }
            }
        }

        if (isset($request->lifestyle))
        {
            $size2 = sizeof($request->lifestyle);
            if($size2>0)
            {
                UserLifestyle::where('userid',Auth::guard('host')->user()->id)->delete();
                for($iii=0;$iii<$size2;$iii++)
                {
                    $lif['userid'] = Auth::guard('host')->user()->id;
                    $lif['lifestyleid'] = $request->lifestyle[$iii];
                    UserLifestyle::create($lif);
                }
            }
        }

        return back()->with('success', __('language.successfully_added'));
    }

    public function update_host_detail(Request $request)
    {
        $GetData = User::findOrFail(Auth::guard('host')->user()->id);
        $GetData->accommodation = $request->accommodation;
        $GetData->what_else = $request->what_else;
        $GetData->update();
        if (isset($request->languages))
        {
            $size2 = sizeof($request->languages);
            if($size2>0)
            {
                UserLanguages::where('userid',Auth::guard('host')->user()->id)->delete();
                for($iii=0;$iii<$size2;$iii++)
                {
                    $lif['userid'] = Auth::guard('host')->user()->id;
                    $lif['name'] = $request->languages[$iii];
                    UserLanguages::create($lif);
                }
            }
        }
        return back()->with('success', __('language.successfully_updated'));
    }

    public function delete_host_images($id)
    {
        $getData = UserImages::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {

            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }
        $getData->delete();
        return back()->with('success', __('language.successfully_deleted'));
    }

    public function chat()
    {
        return view("host.chat");
    }

    public function tourlist()
    {
        $tours = Tours::where('userid',Auth::guard('host')->user()->id)->orderBy('id','desc')->get();
        return view("host.tourlist",compact('tours'));
    }

    public function add_tours()
    {
        $categories = TourCategories::all();
        return view("host.add_tours",compact('categories'));
    }

    public function save_host_tour(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'category' => 'required|numeric',
            'heading' => 'required|string|max:255',
            'image' => 'required',
            'location' => 'required',
            'duration' => 'required',
            'description' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'Heading , Category & Description Required .');
        }
        $validator1 = Validator::make($request->all(), [
            'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
        ]);

        if ($validator1->fails()) {
            return back()->with('error', 'Image Must be in jpg,png,jpeg,gif,svg.');
        }

        $data['userid'] = Auth::guard('host')->user()->id;
        $data['heading'] = $request->heading;
        $data['category'] = $request->category;
        $data['location'] = $request->location;
        $data['description'] = $request->description;
        $data['duration'] = $request->duration;
        $data['status'] = $request->status;
        $data['slug'] = Str::slug($request->heading);

//        check slug already exist
        $CheckSlug = Tours::where('slug', Str::slug($request->heading))->count();
        if ($CheckSlug > 0) {
            return back()->with('error', 'This heading is already exist .');
        }
//        dd($data);
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $image_new = rand(1000,1000000)."-".time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $data['image'] = $image_new;
        }
        $Toursdetail = Tours::create($data);

        return redirect()->route('host.tourlist')->with('success', __('language.successfully_added'));
    }

    public function edittour($id)
    {
        $tour = Tours::findOrFail(decrypt($id));
        $categories = TourCategories::all();
        $setting = Setting::first();
        return view('host.edittour', compact('tour', 'categories', 'setting'));
    }

    public function update_host_tour(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'category' => 'required|numeric',
            'heading' => 'required|string|max:255',
            'description' => 'required',
            'location' => 'required',
            'duration' => 'required',
            'id' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'Heading , Category and Description Required .');
        }

        $getData = Tours::findOrFail(decrypt($request->id));
        if (isset($request->heading)) {
            $getData->heading = $request->heading;
        }
        if (isset($request->category)) {
            $getData->category = $request->category;
        }
        if (isset($request->description)) {
            $getData->description = $request->description;
        }
        if (isset($request->status)) {
            $getData->status = $request->status;
        }
        if (isset($request->location)) {
            $getData->location = $request->location;
        }

         if (isset($request->duration)) {
            $getData->duration = $request->duration;
        }

        $CheckSlug = Tours::where('slug', Str::slug($request->heading))->where('id', '!=', decrypt($request->id))->count();
        if ($CheckSlug > 0) {
            return back()->with('error', 'This heading is already exist .');
        } else {
            $getData->slug = Str::slug($request->heading);
        }

        if ($request->hasFile('image')) {

            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Invalid Image');
            }

            if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {

                \File::delete(public_path('admin/assets/uploads/' . $getData->image));
            }

            $image = $request->file('image');
            $image_new = rand(1000,1000000)."-".time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $getData->image = $image_new;
        }


        $getData->save();

        return redirect()->route('host.tourlist')->with('success', __('language.successfully_updated'));
    }

    public function edit_tour_images($id)
    {
        $tour = Tours::findOrFail(decrypt($id));
        return view('host.edit_tour_images', compact('tour'));
    }

    public function savetourimages(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'tourid' => 'required',
            'image' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $data['image'] = $image_new;
            $data['tourid'] = $request->tourid;
            Tourimages::create($data);
        }
        return redirect()->back()->with('success', 'Successfully Added.');
    }

    public function delete_tour_image($id)
    {
        $getData = Tourimages::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {
            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function deletetour($id)
    {
        $getData = Tours::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {
            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }

        if (!empty($getData->images)) {
            foreach ($getData->images as $images_image) {
                if (\File::exists(public_path('admin/assets/uploads/' . $images_image->image))) {
                    \File::delete(public_path('admin/assets/uploads/' . $images_image->image));
                }
            }
        }
        Tourimages::where('tourid',decrypt($id))->delete();
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }


}
