<?php

namespace App\Http\Controllers;

use App\Models\Cart;
use App\Models\OrderDetails;
use App\Models\Orders;
use App\Models\Record;
use App\Models\Setting;
use App\Models\StripeCustomer;
use App\Models\Subscription;
use App\Models\SubscriptionHistory;
use App\Models\User;
use Hash;
use Illuminate\Http\Request;
use Validator;
use Auth;
use Carbon\Carbon;

class StripeController extends Controller
{

    public function purchase_subscription(Request $request)
    {
        $subscription = Subscription::findOrFail($request->subscriptionid);
        try {
            $sk = Setting::first()->stripe_secret;
            $cc = Setting::first()->currency_code;
            $stripe = new \Stripe\StripeClient($sk);
            $customer = $stripe->customers->create([
                'description' => "Purchase Subscription",
            ]);

            $order = SubscriptionHistory::create([
                'orderid' => rand(1000, 100000),
                'userid' => Auth::guard('web')->user()->id,
                'subscriptionid' => $subscription->id,
                'heading' => $subscription->heading,
                'currency' => Setting::first()->currency_code,
                'symbol' => Setting::first()->currency_symbol,
                'price' => $subscription->price,
                'days' => $subscription->days,
                'start_date' => Carbon::now(),
                'end_date' => Carbon::now()->addDays(intval($subscription->days)),
            ]);


            StripeCustomer::create([
                'user_id' => Auth::guard('web')->user()->id,
                'customer_id' => $customer->id,
                'orderid' => $order->id,
            ]);

            $session = $stripe->checkout->sessions->create([
                'customer' => $customer,
                'line_items' => [
                    [
                        'price_data' => [
                            'currency' => $cc,
                            'product_data' => [
                                'name' => 'Purchase TheWebTrip Subscription'
                            ],
                            'unit_amount' => $subscription->price * 100
                        ],
                        'quantity' => 1,
                    ],
                ],
                'mode' => 'payment',
                'success_url' => url('/user/successpayment?session_id={CHECKOUT_SESSION_ID}&order_id=' . encrypt($order->id)),
                'cancel_url' => route('subscriptions'),
            ]);
            return redirect()->away($session->url);
        } catch (Exception $e) {
            return back()->withError($e->getMessage());
        }

    }

    public function successpayment(Request $request)
    {
        $sessionid = $request->session_id;
        $orderid = $request->order_id;

        $secret_key = Setting::first()->stripe_secret;
        $stripe = new \Stripe\StripeClient($secret_key);
        $session = $stripe->checkout->sessions->retrieve(
            $sessionid
        );
        if ($session->payment_status == 'paid') {
            $existing = SubscriptionHistory::findOrFail(decrypt($orderid));
            $existing->update([
                'payment_status' => 'paid'
            ]);
        }
        return redirect()->route('/')->with('success', 'Successfully Purchased.');
    }


}
