<?php

namespace App\Http\Controllers;

use App\Mail\AccountConfirmation;
use App\Mail\PasswordResetMail;
use App\Models\Blogs;
use App\Models\Blogs_tags;
use App\Models\Blogscategories;
use App\Models\ContactMessage;
use App\Models\Instagramimages;
use App\Models\Setting;
use App\Models\Subscription;
use App\Models\SubscriptionHistory;
use App\Models\TourCategories;
use App\Models\Tours;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Mail;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;

class WebsiteController extends Controller
{
    public function home()
    {
        $query = Blogs::where('status', 'active');
        $blogs = $query->orderBy('id', 'desc')->with(['blog_tags_data'])->limit(3)->get();
        $setting = Setting::first();
        $hosts = User::where('type','host')->where('status','active')->get();
        return view("website.home", compact('blogs', 'setting','hosts'));
    }

    public function about()
    {
        $hosts = User::where('type','host')->where('status','active')->get();
        $images = Instagramimages::all();
        return view("website.about",compact('hosts','images'));
    }

    public function contact()
    {
        $system = Setting::first();
        return view("website.contact", compact('system'));
    }

    public function save_contact_message(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required',
            'subject' => 'required',
            'message' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->withInput()->with('error', 'All fields required !');
        }
        $data['name'] = $request->name;
        $data['email'] = $request->email;
        $data['subject'] = $request->subject;
        $data['message'] = $request->message;
        $contactdetail = ContactMessage::create($data);
        return back()->with('success', 'Message Sent Successfully.');
//        $maildata = ContactMessage::findOrFail($contactdetail->id);
//        $check = Mail::to("info@sourcesync.co.uk")->send(new ContactMessages($maildata));
//        if ($check) {
//            return back()->with('success', 'Message Sent Successfully.');
//        } else {
//            return back()->with('error', 'Message Not Sent.');
//        }
    }

    public function privacy()
    {
        return view("website.privacy");
    }

    public function terms()
    {
        return view("website.terms");
    }

    public function faq()
    {
        return view("website.faq");
    }

    public function forget()
    {
        return view("website.forget");
    }

    public function resetpassword(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email' => 'required'
        ]);
        if ($validator->fails()) {
            return back()
                ->withInput()
                ->withErrors($validator)->with('error', 'Email Required.')->with('error', 'Email required.');
        }

        $check = User::where('email', $request->email)->where('type', '!=', 'admin')->first();
        $setting = Setting::first();
        if ($check) {
            if ($check->status == "active") {

                $check->remember_token = Str::random(30);
                $check->save();
                $maildata = $check;
                Mail::to($request->email)->send(new PasswordResetMail($check));
                return redirect()->route('login')->with('success', 'Password Sent ! Please Check your email.')->with('success', 'Password Sent ! Please Check your email.');
            } else {
                return back()
                    ->withInput()
                    ->withErrors('Your account is not active please contact with customer support.')->with('error', 'Your account is not active please contact with customer support.');
            }
        } else {
            return back()
                ->withInput()
                ->withErrors('Invalid email !Please enter valid email ')->with('error', 'Invalid Email.');
        }

    }

    public function resetnewpassword($email)
    {
        $decemail = decrypt($email);
        $check = User::where('email', $decemail)->whereNotNull('remember_token')->count();
        if ($check > 0) {
            return view('website.resetnewpassword', compact('email'));
        } else {
            return redirect()->route('login')->with('error', 'Link Expired Please Reset Your Password Again !');
        }
    }

    public function saveresetnewpassword(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'password' => 'min:8|required_with:password_confirmation|same:password_confirmation',
            'password_confirmation' => 'min:8'
        ]);
        if ($validator->fails()) {
            return back()
                ->withInput()
                ->withErrors($validator)->with('error', 'Password Not Match / Required.')->with('error', 'Password Not Match / Required.');
        }

        $email = decrypt($request->id);
        $user = User::where('email', $email)->first();
        $user->password = Hash::make($request->password);;
        $user->remember_token = NULL;
        $user->save();
        return redirect()->route('login')->with('success', 'Password Successfully Updated !');
    }

    public function profile()
    {
        return view("website.profile");
    }

    public function updateuserprofile(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'address' => 'required',
            'phone' => 'required'
        ]);
        if ($validator->fails()) {
            return back()->withErrors($validator);
        }

//        update user
        $getData = user::findOrFail(Auth::guard('web')->user()->id);
        $getData->name = $request->name;
        $getData->phone = $request->phone;
        $getData->address = $request->address;
        $getData->country = $request->country;
        $getData->city = $request->city;
        $getData->postalcode = $request->postalcode;
        $getData->about_me = $request->about_me;
        if (isset($request->password)) {
            $validator = Validator::make($request->all(), [
                'password' => 'required|min:8'
            ]);
            if ($validator->fails()) {
                return redirect()->back()->with('error', 'Minimum 8 Characters Required for password.');
            }
            $getData->password = Hash::make($request->password);
        }
        if ($request->hasFile('profile_picture')) {
            $validator = Validator::make($request->all(), [
                'profile_picture' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Invalid Profile Picture');
            }

            if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {

                \File::delete(public_path('admin/assets/uploads/' . $getData->image));
            }

            $image = $request->file('profile_picture');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $getData->image = $image_new;
        }
        $getData->save();
        return redirect()->back()->with('success', 'Data Successfully Updated !');
    }

    public function login()
    {
        if (Auth::guard('web')->check()) {
            return redirect()->route('/');

        } else {
            return view("website.login");
        }
    }

    public function customerlogin(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email' => 'required',
            'password' => 'required|min:8'
        ]);
        if ($validator->fails()) {
            return back()->withInput()->withErrors($validator);
        }
        if ($request->type == "user") {
            if (Auth::guard('web')->attempt(['email' => $request->email, 'password' => $request->password, 'type' => $request->type])) {
                if (Auth::guard('web')->user()->status == "inactive") {
                    Auth::guard('web')->logout();
                    return redirect()->back()->with('error', 'Account Inactive / Blocked ! Please Contact with Customer support.')->withErrors("Account Inactive / Blocked ! Please Contact with Customer support.");
                } else {
                    if (Auth::guard('web')->user()->email_verification == "0") {
                        Auth::guard('web')->logout();
                        return redirect()->back()->with('error', 'Email Not Verified.Please verify your email.')->withErrors("Email Not Verified.Please verify your email.");
                    } else {
                        if (Auth::guard('web')->check()) {
                            return redirect()->route('/');
                        }
                    }
                }
            } else {
                return redirect()->back()->with('error', 'Invalid Email or Password !')->withInput()->withErrors("Invalid Email or Password !");
            }
        } else {
            if (Auth::guard('host')->attempt(['email' => $request->email, 'password' => $request->password, 'type' => $request->type])) {
                if (Auth::guard('host')->user()->status == "inactive") {
                    Auth::guard('host')->logout();
                    return redirect()->back()->with('error', 'Account Inactive / Blocked ! Please Contact with Customer support.')->withErrors("Account Inactive / Blocked ! Please Contact with Customer support.");
                } else {
                    if (Auth::guard('host')->user()->email_verification == "0") {
                        Auth::guard('host')->logout();
                        return redirect()->back()->with('error', 'Email Not Verified.Please verify your email.')->withErrors("Email Not Verified.Please verify your email.");
                    } else {
                        if (Auth::guard('host')->check()) {
                            return redirect()->route('/');
                        }
                    }
                }
            } else {
                return redirect()->back()->with('error', 'Invalid Email or Password !')->withInput()->withErrors("Invalid Email or Password !");
            }
        }

    }

    public function register()
    {
        return view("website.register");
    }

    public function save_register_user(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'firstname' => 'required',
            'lastname' => 'required',
            'email' => 'required|unique:users,email',
            'phone' => 'required',
            'password' => 'min:8|required_with:password_confirmation|same:password_confirmation',
            'password_confirmation' => 'min:8'
        ]);
        if ($validator->fails()) {
            return back()->withInput()->withErrors($validator)->with('error', 'Registration Failed.');
        }
        $data['name'] = $request->firstname . " " . $request->lastname;
        $data['fname'] = $request->firstname;
        $data['lname'] = $request->lastname;
        $data['email'] = $request->email;
        $data['phone'] = $request->phone;
        $data['password'] = Hash::make($request->password);
        $data['status'] = "inactive";
        $data['type'] = $request->type;
        $userdata = User::create($data);
        $maildata = $userdata;
//        return view('website.emails.accountconfirmation',compact('maildata'));
        Mail::to($request->email)->send(new AccountConfirmation($maildata));
        return redirect()->route('login')->with('success', 'Successfully Registered. Please Check your Email.');
    }

    public function verifyaccount($id)
    {
        $id = decrypt($id);
        $user = User::findOrFail($id);
        if ($user->email_verification == "0") {
            $user->email_verified_at = Carbon::now();
            $user->email_verification = "1";
            $user->status = "active";
            $user->save();
            return redirect()->route('login')->with('success', 'Email Verified Successfully');
        } else {
            return redirect()->route('login')->with('error', 'Already Verified.');
        }

    }

    public function blog(Request $request)
    {
        $query = Blogs::where('status', 'active');
        if (isset($request->category) && !empty($request->category)) {
            $query->where('category', $request->category);
        }
        if (isset($request->search) && !empty($request->search)) {
            $query->where('heading', 'like', '%' . $request->search . '%');
        }
        $blogs = $query->orderBy('id', 'desc')->with(['blog_tags_data'])->paginate(5);
        $setting = Setting::first();
        $blogcategories = Blogscategories::all();
        $admin = User::where('type', 'admin')->first();
        $randomtags = Blogs_tags::inRandomOrder()->limit(6)->get();
        return view("website.blog", compact('blogs', 'setting', 'blogcategories', 'admin', 'request', 'randomtags'));
    }

    public function blogdetails($slug, Request $request)
    {
        $blog = Blogs::where('slug', $slug)->first();
        $randomblogs = Blogs::inRandomOrder()->limit(3)->get();
        $setting = Setting::first();
        $blogcategories = Blogscategories::all();
        $admin = User::where('type', 'admin')->first();
        $randomtags = Blogs_tags::inRandomOrder()->limit(6)->get();
        return view("website.blogdetails", compact('blog', 'setting', 'blogcategories', 'admin', 'randomblogs', 'randomtags', 'request'));
    }

    public function hosts()
    {
        return view("website.hosts");
    }

    public function tourslist(Request $request,$id)
    {
        $category = TourCategories::where('slug',$id)->first();
        $query = Tours::where('status', 'active')->where('category',$category->id);
//        $query = Tours::where('status', 'active');
        if (isset($request->category) && !empty($request->category)) {
            $query->where('category', $request->category);
        }
        if (isset($request->search) && !empty($request->search)) {
            $query->where('heading', 'like', '%' . $request->search . '%');
        }
        $tours = $query->orderBy('id', 'desc')->paginate(12);
        $categories = TourCategories::all();
        $setting = Setting::first();
        return view("website.tours",compact('tours','categories','category','request'));
    }

    public function tour_detail($id)
    {
        $tour = Tours::where('slug',$id)->first();
        $setting = Setting::first();
        $relatedtours = Tours::where('category',$tour->category)->limit(6)->get();
        return view("website.tour_detail",compact('tour','relatedtours','setting'));
    }

    public function hostslist()
    {
        return view("website.hostslist");
    }

    public function hostsdetail()
    {
        return view("website.hostsdetail");
    }

    public function subscriptions()
    {
        $subscriptions = Subscription::orderby('id', 'asc')->get();
        $setting = Setting::first();
        return view("website.subscriptions", compact('subscriptions', 'setting'));
    }

    public function chat()
    {
        return view("website.chat");
    }

    public function listings($id)
    {
        $tours = Tours::where('userid',$id)->orderby('id', 'desc')->get();
        return view("website.listings",compact('tours'));
    }

    public function subscription_history()
    {
        $subscriptionHistorys = SubscriptionHistory::where('userid', Auth::guard('web')->user()->id)->get();
        return view("website.subscription_history", compact('subscriptionHistorys'));
    }
}
