@extends('admin.layout.master')

@section('title')
    {{ __('language.add') }} {{ __('language.blogs') }}
@endsection

@section('content')

    <div class="nxl-content without-header nxl-full-content">
        <!-- [ Main Content ] start -->
        <div class="main-content d-flex">
            <!-- [ Main Area  ] start -->
            <div class="content-area" style="height: auto !important;">

                <form method="POST" class="MyForm" action="{{ route('admin.saveblogs') }}"
                      enctype="multipart/form-data">
                    @csrf

                    <div class="content-area-header bg-white sticky-top">
                        <div class="page-header-left pt-3">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item"><a
                                            href="{{ route('admin.dashboard') }}">{{ __('language.home') }}</a></li>
                                <li class="breadcrumb-item">{{ __('language.add') }} {{ __('language.blogs') }}</li>
                            </ul>
                        </div>
                        <div class="page-header-right ms-auto">
                            <div class="d-flex align-items-center gap-3 page-header-right-items-wrapper">
                                <button class="btn btn-primary MyButton">
                                    <i class="feather-save me-2"></i>
                                    <span>{{ __('language.save_changes') }}</span>
                                </button>
                            </div>
                        </div>
                    </div>
                    <div class="content-area-body">
                        <div class="card mb-0">
                            <div class="card-body">

                                <div class="row">

                                    <div class="col-md-12">
                                        <div class="form-group">
                                            <label class="form-label"> {{ __('language.heading') }} </label>
                                            <input type="text" name="heading" class="form-control MyInput"
                                                   placeholder="{{ __('language.heading') }}" required>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label class="form-label"> {{ __('language.categories') }} </label>
                                            <select name="category" class="form-control MyInput" required>
                                                <option value="">{{ __('language.select') }} {{ __('language.categories') }}</option>
                                                @forelse($categories as $category)
                                                    <option value="{{ $category->id }}">{{ $category->name }}</option>
                                                @empty
                                                @endforelse
                                            </select>
                                        </div>
                                    </div>

                                    <div class="col-md-6">
                                        <label class="form-label">{{ __('language.status') }}</label>
                                        <select class="form-select" data-select2-selector="icon" name="status"
                                                style="height: 60px !important;">
                                            <option value="active" data-icon="feather-check text-success" selected>Active
                                            </option>
                                            <option value="inactive" data-icon="feather-x text-danger">Inactive</option>
                                        </select>
                                    </div>

                                </div>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="form-group">
                                            <label class="form-label"> {{ __('language.blogs') }} {{ __('language.image') }} </label>
                                            <input type="file" class="form-control mb-3 MyFileInput" autocomplete="off"
                                                   style="padding-top: 17px"
                                                   name="image" id="image" required onchange="validateImages(this.id)"
                                                   accept="image/*">
                                        </div>
                                    </div>

                                </div>

                                <div class="row">
                                    <div class="col-md-10">
                                        <label> {{ __('language.tags') }} </label>
                                        <input type="text" name="tags[]" class="form-control MyInput"
                                               placeholder="{{ __('language.tags') }}" required>
                                    </div>
                                    <div class="col-md-2">
                                        <button class="btn btn-info w-100" type="button" onclick="AddMore()"
                                                style="margin-top:21px;height:57px">{{ __('language.add_more') }}
                                        </button>
                                    </div>
                                </div>
                                <div class="row">
                                    <div id="append"></div>
                                </div>


                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="form-group">
                                            <label class="form-label"> {{ __('language.description') }} </label>
                                            <textarea name="description" class="form-control Description_1"
                                                      placeholder="{{ __('language.description') }}"
                                                      id="tinymceExample1" rows="10"></textarea>
                                        </div>
                                    </div>

                                </div>

                            </div>
                        </div>
                    </div>

                </form>
            </div>
            <!-- [ Content Area ] end -->
        </div>
        <!-- [ Main Content ] end -->
    </div>

@endsection
@section('script')

    <script>
        var useDarkMode = window.matchMedia('(prefers-color-scheme: dark)').matches;

        tinymce.init({
            selector: 'textarea',
            plugins: 'print preview paste importcss searchreplace autolink autosave save directionality code visualblocks visualchars fullscreen image link media template codesample table charmap hr pagebreak nonbreaking anchor toc insertdatetime advlist lists wordcount imagetools textpattern noneditable help charmap quickbars emoticons',
            imagetools_cors_hosts: ['picsum.photos'],
            menubar: 'file edit view insert format tools table help',
            toolbar: 'undo redo | bold italic underline strikethrough | fontselect fontsizeselect formatselect | alignleft aligncenter alignright alignjustify | outdent indent |  numlist bullist | forecolor backcolor removeformat | pagebreak | charmap emoticons | fullscreen  preview save print | insertfile image media template link anchor codesample | ltr rtl',
            toolbar_sticky: true,
            autosave_ask_before_unload: true,
            autosave_interval: '30s',
            autosave_prefix: '{path}{query}-{id}-',
            autosave_restore_when_empty: false,
            autosave_retention: '2m',
            image_advtab: true,
            link_list: [
                {title: 'My page 1', value: 'https://www.tiny.cloud'},
                {title: 'My page 2', value: 'http://www.moxiecode.com'}
            ],
            image_list: [
                {title: 'My page 1', value: 'https://www.tiny.cloud'},
                {title: 'My page 2', value: 'http://www.moxiecode.com'}
            ],
            image_class_list: [
                {title: 'None', value: ''},
                {title: 'Some class', value: 'class-name'}
            ],
            importcss_append: true,
            file_picker_callback: function (callback, value, meta) {
                /* Provide file and text for the link dialog */
                if (meta.filetype === 'file') {
                    callback('https://www.google.com/logos/google.jpg', {text: 'My text'});
                }

                /* Provide image and alt text for the image dialog */
                if (meta.filetype === 'image') {
                    callback('https://www.google.com/logos/google.jpg', {alt: 'My alt text'});
                }

                /* Provide alternative source and posted for the media dialog */
                if (meta.filetype === 'media') {
                    callback('movie.mp4', {source2: 'alt.ogg', poster: 'https://www.google.com/logos/google.jpg'});
                }
            },
            templates: [
                {
                    title: 'New Table',
                    description: 'creates a new table',
                    content: '<div class="mceTmpl"><table width="98%%"  border="0" cellspacing="0" cellpadding="0"><tr><th scope="col"> </th><th scope="col"> </th></tr><tr><td> </td><td> </td></tr></table></div>'
                },
                {title: 'Starting my story', description: 'A cure for writers block', content: 'Once upon a time...'},
                {
                    title: 'New list with dates',
                    description: 'New List with dates',
                    content: '<div class="mceTmpl"><span class="cdate">cdate</span><br /><span class="mdate">mdate</span><h2>My List</h2><ul><li></li><li></li></ul></div>'
                }
            ],
            template_cdate_format: '[Date Created (CDATE): %m/%d/%Y : %H:%M:%S]',
            template_mdate_format: '[Date Modified (MDATE): %m/%d/%Y : %H:%M:%S]',
            height: 600,
            image_caption: true,
            quickbars_selection_toolbar: 'bold italic | quicklink h2 h3 blockquote quickimage quicktable',
            noneditable_noneditable_class: 'mceNonEditable',
            toolbar_mode: 'sliding',
            contextmenu: 'link image imagetools table',
            skin: useDarkMode ? 'oxide-dark' : 'oxide',
            content_css: useDarkMode ? 'dark' : 'default',
            content_style: 'body { font-family:Helvetica,Arial,sans-serif; font-size:14px }'
        });
    </script>

    <script>


        var count = 1;

        function AddMore() {

            var detail = `<div class="row" id="append_` + count + `">
                                    <div class="col-md-10">
                                        <label> {{ __('language.tags') }} </label>
                                        <input type="text" name="tags[]" class="form-control MyInput"
                                               placeholder="{{ __('language.tags') }}" required>
                                    </div>
                                    <div class="col-md-2">
                                        <button class="btn btn-danger w-100" type="button" onclick="Remove(` + count + `)"
                                                style="margin-top:21px;height:57px"> {{ __('language.remove') }}
            </button>
        </div>
    </div>`;
            $("#append").append(detail);
            count++;
        }

        function Remove(id) {
            $("#append_" + (count-1)).remove();
            count--;
        }

    </script>

@endsection